@@ -57,7 +57,8 @@ class Options:
     def require_authentication(self):
         self.authentication = self.find_authentication()
         if self.authentication is None:
-            print_error("You are not logged in", exit=True)
+            print_error("You are not logged in. Please run:\n"
+                "hpackage auth login", exit=True)
         return self.authentication
 
 
@@ -75,6 +76,10 @@ def create_parser():
 
     subparsers = parser.add_subparsers(dest="command", required=True)
 
+    # version command
+    subparsers.add_parser(
+        "version", help="print the version of this program")
+
     # auth subcommand:
     auth_parser = subparsers.add_parser("auth", help="authentication commands")
     auth_subparsers = auth_parser.add_subparsers(dest="auth_cmd", required=True)
@@ -204,7 +209,9 @@ def main():
             print_error("The timeout is not an integer")
 
     # Dispatch to the appropriate handler
-    if args.command == "auth":
+    if args.command == "version":
+        print("hpackage", __version__)
+    elif args.command == "auth":
         if args.auth_cmd == "login":
             log_in()
         elif args.auth_cmd == "logout":
@@ -481,14 +488,12 @@ def upgrade(package_name):
     package_name, version, _info = _get_package_info_from_name(
         package_name, authentication)
 
-    # Make sure the package is installed and it's not already at this version.
+    # Check if the package is installed and it's not already at this version.
     installed_info = _installed_packages().get(package_name)
-    if installed_info is None:
-        print_error(f"{package_name} is not installed")
-
-    if installed_info.get("version") == version:
-        print_error(f"{package_name}=={version} is already installed and"
+    if installed_info and installed_info.get("version") == version:
+        print(f"{package_name}=={version} is already installed and"
             " is the latest version")
+        return
 
     # Uninstall the old version and install the new one.
     installation_dir = None
@@ -1189,8 +1194,14 @@ def _houdini_user_pref_dir():
     return os.path.expandvars({
         "Linux": f"$HOME/houdini{major_minor}",
         "Windows": f"%USERPROFILE%/houdini{major_minor}",
+        "Cygwin": f"$USERPROFILE/houdini{major_minor}",
         "Darwin": f"$HOME/Library/Preferences/houdini/{major_minor}",
-    }[platform.system()])
+    }[_get_platform_system()])
+
+
+def _get_platform_system():
+    system = platform.system()
+    return ("Cygwin" if system.lower().startswith("cygwin") else system)
 
 
 @functools.cache
@@ -1234,10 +1245,13 @@ def _find_hfs():
     if hfs:
         hfs_dirs.append(hfs)
 
-    # TODO: Support Mac.
-    if platform.system() == "Linux":
+    platform_system = _get_platform_system()
+    if platform_system == "Linux":
         hfs_dirs.extend(sorted(glob.glob("/opt/hfs*.*.*"), reverse=True))
-    elif platform.system() == "Windows":
+    elif platform_system == "Darwin":
+        hfs_dirs.extend(sorted(
+            glob.glob("/Applications/Houdini/Houdini*.*.*"), reverse=True))
+    elif platform_system in ("Windows", "Cygwin"):
         hfs_dirs.extend(get_hfs_dirs_from_registry())
 
     for hfs in hfs_dirs:
@@ -1409,15 +1423,21 @@ def _find_oauth_keys():
 
 
 def _find_hserver_ini_paths(mode):
-    if platform.system() == "Windows":
+    platform_system = _get_platform_system()
+    if platform_system == "Windows":
         paths = ["%SystemDrive%/ProgramData/SideFX",
             "%USERPROFILE%/AppData/Roaming/SideFX"]
-    elif platform.system() == "Darwin":
+    elif platform_system == "Cygwin":
+        paths = ["$SystemDrive/ProgramData/SideFX",
+            "$USERPROFILE/AppData/Roaming/SideFX"]
+    elif platform_system == "Darwin":
         paths = ["/Library/Preferences/sesi/hserver",
             "$HOME/Library/Application Support/sidefx"]
-    else:
+    elif platform_system == "Linux":
         paths = ["/usr/lib/sesi/hserver",
             "$HOME/.local/share/sidefx"]
+    else:
+        print_error(f"Unsupported platform: {platform_system}")
 
     for path in paths:
         path = Path(os.path.expandvars(path)) / "hserver.ini"
@@ -1649,7 +1669,8 @@ def _start_hserver():
     if not hfs:
         return False
 
-    extension = (".exe" if platform.system() == "Windows" else "")
+    extension = (".exe"if _get_platform_system() in ("Windows", "Cygwin")
+        else "")
     result = subprocess.run([f"{hfs}/bin/hserver{extension}"], check=False)
     if result.returncode:
         return False
@@ -1712,6 +1733,8 @@ def _call_sidefx(function, authentication, *args, **kwargs):
                 "application/octet-stream")
             kwargs.pop(arg_name)
 
+    kwargs["client_version"] = __version__
+
     response = _post_to_sidefx(
         "/api/", authentication, {"json": json.dumps([function, args, kwargs])},
         file_data=file_data, allowed_statuses=(200, 422))
@@ -1999,5 +2022,34 @@ def _b64encode_text(text):
     return base64.b64encode(text.encode()).decode()
 
 
+def _get_package_version():
+    # Determine the package version, first checking to see if we're running
+    # from source instead of an installed pip package.  Note that importlib was
+    # called importlib_metadata prior to Python 3.8 so we don't try importing
+    # it until after the version check at startup.
+    project_path = Path(__file__).resolve().parent.parent / "pyproject.toml"
+    if not project_path.exists():
+        import importlib.metadata
+        return importlib.metadata.version("hpackage")
+
+    # Note that tomllib was aded to the standard library in Python 3.11, and
+    # for versions prior to that developers need to install tomli.
+    try:
+        import tomllib
+    except ImportError:
+        try:
+            import tomli as tomllib
+        except ImportError:
+            print_error("You are running a development version of hpackage."
+                " Please run:\npip install tomli")
+
+    with project_path.open("rb") as open_file:
+        project_info = tomllib.load(open_file)
+    return project_info["project"]["version"]
+
+
+__version__ = _get_package_version()
+
+
 if __name__ == "__main__":
     main()
